@@ -24,7 +24,7 @@
 # THE SOFTWARE.
 #
 #--------------------------------------------------------------------------
-""" Client for the Batch Apps Managment API.
+""" Client for the Batch Apps Management API.
 """
 
 from batchapps import rest_client
@@ -55,7 +55,7 @@ class Response(object):
 
         :Kwargs:
             - output: The response from the REST client. This could be the
-              result of a successful api call, or it could hold exception
+              result of a successful API call, or it could hold exception
               information for a failed call. Defaults to None.
         """
         self.success = success
@@ -70,16 +70,20 @@ class BatchAppsApi(object):
 
     :Attributes:
         - headers (dict)
+
     """
 
     def __init__(self, credentials, config):
         """
+        Create new API client:
+
         :Args:
             - credentials (:class:`.Credentials`): Credentials with which all
               API calls will be authenticated.
             - config (:class:`.Configuration`): Configuration of the
               job type the jobs will be submitted as, as well as endpoint
               and logging configuration.
+
         """
         self._config = config
         self._log = logging.getLogger('batch_apps')
@@ -92,6 +96,7 @@ class BatchAppsApi(object):
     def app(self):
         """
         .. warning:: Deprecated. Use :meth:`.jobtype()`.
+
         Retrieve the current jobtype from the :class:`.Configuration`.
 
         :Returns:
@@ -122,7 +127,7 @@ class BatchAppsApi(object):
             - The complete, formatted URL (str)
         """
         end_p = self._config.endpoint()
-        self._log.debug("Formatting url: https://{endpoint}/api/{api}".format(
+        self._log.debug("Formatting URL: https://{endpoint}/api/{api}".format(
             endpoint=end_p,
             api=api_call))
 
@@ -146,11 +151,12 @@ class BatchAppsApi(object):
 
         :Kwargs:
             - index (int): The starting index from which the list of jobs will
-              be returned. Default is 0, i.e. return all jobs from the start.
+              be returned. The default is 0, i.e. return all jobs from the
+              start.
             - per_call (int): The number of job entries from ``index`` to
-              return. Default is 10.
+              return. The default is 10.
             - name (str): Return only the jobs whose name contains the given
-              string. Default is None.
+              string. The default is None.
 
         :Returns:
             - :class:`.Response` object containing success of call. If
@@ -177,8 +183,9 @@ class BatchAppsApi(object):
             return Response(False, exp)
 
         else:
-            if utils.valid_keys(get_resp, ['totalCount', 'jobs']):
+            if 'jobs' in get_resp:
                 return Response(True, get_resp)
+
             return Response(
                 False,
                 RestCallException(KeyError,
@@ -192,7 +199,7 @@ class BatchAppsApi(object):
         **or** a URL to the job. If both are supplied, URL is used.
 
         :Kwargs:
-            - job_id (str): Guid of the job on which info is requested.
+            - job_id (str): ID of the job on which info is requested.
             - url (str): A complete URL to the job info.
 
         :Returns:
@@ -263,6 +270,7 @@ class BatchAppsApi(object):
         else:
             if utils.valid_keys(post_resp, ['jobId', 'link']):
                 return Response(True, post_resp)
+
             return Response(
                 False,
                 RestCallException(KeyError,
@@ -276,14 +284,14 @@ class BatchAppsApi(object):
         application.
 
         :Args:
-            - job_id (str): The guid of the job on which to download the logs.
+            - job_id (str): The ID of the job on which to download the logs.
 
         :Kwargs:
             - start (str): The start time from which the logs will be
               downloaded. If not specified, the default is from the
               beginning of the job.
             - max_lines (int): The max number of logging messages to retrieve.
-              Default is 100. If set to ``None``, all messages from start
+              The default is 100. If set to ``None``, all messages from start
               time will be retrieved.
 
         :Returns:
@@ -323,7 +331,7 @@ class BatchAppsApi(object):
         """Cancels a running job.
 
         :Args:
-            - job_id (str): guid of the job to be cancelled.
+            - job_id (str): The ID of the job to be cancelled.
 
         :Returns:
             - A :class:`.Response` object with the POST response, however this
@@ -412,7 +420,7 @@ class BatchAppsApi(object):
                                   "jobOutputs key not in response message",
                                   get_resp))
 
-        # Reformat output dictrionary to be more manageable
+        # Reformat output dictionary to be more manageable
         for output in get_resp['jobOutputs']:
             outputs.append({
                 'name': output.get('name'),
@@ -445,12 +453,12 @@ class BatchAppsApi(object):
 
         :Kwargs:
             - job_id (str): The ID of the job whose output will be downloaded.
-              Default is None.
+              The default is None.
             - otype (str): The type of output to be downloaded, must be a
               string in ``['output', 'preview']``.
             - url (str): The URL directly to the file to be downloaded. If
               supplied, ``job_id`` and ``otype`` will not be used.
-              Default is None.
+              The default is None.
 
         :Returns:
             - :class:`.Response` with the GET response, however this is not
@@ -515,12 +523,12 @@ class BatchAppsApi(object):
 
         :Kwargs:
             - job_id (str): The ID of the job whose output will be checked.
-              Default is None.
+              The default is None.
             - otype (str): The type of output to be checked, must be a
               string in ``['output', 'preview']``.
             - url (str): The URL directly to the file to be checked. If
               supplied, ``job_id`` and ``otype`` will not be used.
-              Default is None.
+              The default is None.
 
         :Returns:
             - :class:`.Response` with the requested output size in bytes (int)
@@ -623,10 +631,10 @@ class BatchAppsApi(object):
 
         :Kwargs:
             - job_id (str): The ID of the job whose output will be downloaded.
-              Default is None.
+              The default is None.
             - fname (str): The name of the output file to be downloaded.
             - url (str): The URL directly to the file to be downloaded.
-              Default is None.
+              The default is None.
 
         :Returns:
             - :class:`.Response` with the GET response, however this is not
@@ -683,10 +691,10 @@ class BatchAppsApi(object):
 
         :Kwargs:
             - job_id (str): The ID of the job whose output will be checked.
-              Default is None.
+              The default is None.
             - fname (str): The name of the output file to be downloaded.
             - url (str): The URL directly to the file to be checked.
-              Default is None.
+              The default is None.
 
         :Returns:
             - :class:`.Response` with the requested output size in bytes (int)
@@ -727,13 +735,13 @@ class BatchAppsApi(object):
 
         :Kwargs:
             - job_id (str): ID of of the job to list the tasks for.
-              Default is None.
+              The default is None.
             - url (str): Direct URL to the task list of the job
               (supplied by :meth:`.BatchAppsApi.get_job()`)
 
         :Returns:
             - A :class:`.Response` object containing the list of task
-              dictionaries if the call is successfull.
+              dictionaries if the call is successful.
             - A :class:`.Response` object containing the
               :class:`.RestCallException` is the call failed.
         """
@@ -1009,7 +1017,7 @@ class BatchAppsApi(object):
 
         :Kwargs:
             - overwrite (bool): Whether to overwrite a destination file if it
-              already exists. Default is ``False``.
+              already exists. The default is ``False``.
 
         :Returns:
             - :class:`.Response` with the GET response, however this is not
@@ -1119,3 +1127,174 @@ class BatchAppsApi(object):
 
         else:
             return Response(True, put_resp)
+
+    def add_pool(self, target_size=0, max_tasks=1, communication=False, certs=[]):
+        """
+        Add a new pool.
+
+        :Kwargs:
+            - target_size (int): The target size of the pool. The default is 0.
+            - max_tasks (int): Max tasks that can run on a single TVM.
+              The default is 1.
+            - communication (bool): Indicates whether tasks running on TVMs
+              in the pool need to ba able to communicate directly with each
+              other. The default is ``False``.
+            - certs (list): A list of certificates that need to be installed
+              on the TVMs of the pool. The maximum number of certs that can
+              be installed on a pool is 10.
+
+        :Returns:
+            - A :class:`.Response` object a dict with the new pool id and
+              a link to the newly created pool.
+              ``{'id': '', 'link': ''}``
+            - If the call failed or if the response is incomplete/malformed
+              a :class:`.Response` object with a :class:`.RestCallException`.
+        """
+        self._log.debug("add_pool")
+        url = self.url("pools")
+
+        if len(certs) > 10:
+            certs = certs[0:10]
+
+        try:
+            message = {
+                'targetDedicated': str(int(target_size)),
+                'maxTasksPerTVM': str(int(max_tasks)),
+                'communication': bool(communication),
+                'certificateReferences': list(certs)}
+
+        except ValueError as exp:
+            return Response(
+                False,
+                RestCallException(ValueError, str(exp), exp))
+
+        try:
+            resp = rest_client.post(self._auth, url, self.headers, message)
+
+        except  RestCallException as exp:
+            return Response(False, exp)
+
+        if utils.valid_keys(resp, ['poolId', 'link']):
+                return Response(True, resp)
+
+        return Response(
+            False,
+            RestCallException(KeyError,
+                                "incorrectly formatted pool response",
+                                resp))
+
+    def resize_pool(self, pool_id, target_size):
+        """
+        Resize an existing pool.
+
+        :Args:
+            - pool_id (str): The ID of the pool to be resized.
+            - target_size (int): The new size of the pool.
+
+        :Returns:
+            - :class:`.Response` with the POST response, however this is not
+              required if the call was successful.
+            - If the call failed a :class:`.Response` object with a
+              :class:`.RestCallException`.
+        """
+        self._log.debug("resize_pool, pool_id={0}, "
+                        "target_size={1}".format(pool_id, target_size))
+        url = self.url("pools/{poolid}/actions/resize")
+        url = url.format(url, poolid=pool_id)
+
+        message = {'targetDedicated': str(target_size)}
+
+        try:
+            resp = rest_client.post(self._auth, url, self.headers, message)
+
+        except  RestCallException as exp:
+            return Response(False, exp)
+
+        return Response(True, resp)
+
+    def get_pool(self, pool_id=None, url=None):
+        """
+        Gets information about a pool.
+        Pool info can be retrieved by supplying **either** the pool's ID
+        **or** a URL to the pool. If both are supplied, URL is used.
+
+        :Kwargs:
+            - pool_id (str): ID of the pool on which info is requested.
+            - url (str): A complete URL to the pool info.
+
+        :Returns:
+            - A :class:`.Response` object containing the pool details as a
+              dictionary, if successful. Otherwise the Response will
+              contain the :exc:`.RestCallException`.
+            - :class:`.RestCallException` if neither pool ID or URL are
+              supplied.
+            - :class:`.RestCallException` if pool details dictionary is
+              malformed / missing necessary keys
+        """
+        self._log.debug("get_pool, pool_id={0}, url={1}".format(pool_id, url))
+        if not url and pool_id:
+            url = self.url("pools/{poolid}").format(poolid=pool_id)
+
+        elif not url and not pool_id:
+            return Response(
+                False,
+                RestCallException(AttributeError,
+                                  "Either pool_id or url must be set",
+                                  None))
+
+        try:
+            get_resp = rest_client.get(self._auth, url, self.headers)
+
+        except RestCallException as exp:
+            return Response(False, exp)
+
+        else:
+            return Response(True, get_resp)
+
+    def list_pools(self):
+        """Lists the users pools.
+
+        :Returns:
+            - :class:`.Response` object containing success of call. If
+              successful, the ``Response.result`` will contain a list of
+              pool dictionaries. If failed, ``Response.result`` will
+              hold the :exc:`.RestCallException`.
+        """
+        self._log.debug("list_pools, no params")
+
+        url = self.url("pools")
+
+        try:
+            get_resp = rest_client.get(self._auth, url,
+                                       self.headers)
+
+        except RestCallException as exp:
+            return Response(False, exp)
+
+        else:
+            return Response(True, get_resp)
+
+    def delete_pool(self, pool_id):
+        """
+        Delete an existing pool.
+
+        :Args:
+            - pool_id (str): The ID of the pool to be deleted.
+
+        :Returns:
+            - :class:`.Response` with the POST response, however this is not
+              required if the call was successful.
+            - If the call failed a :class:`.Response` object with a
+              :class:`.RestCallException`.
+        """
+        self._log.debug("delete_pool, no params")
+        url = self.url("pools/{poolid}")
+        url = url.format(url, poolid=pool_id)
+
+        try:
+            resp = rest_client.delete(self._auth, url, self.headers)
+
+        except  RestCallException as exp:
+            return Response(False, exp)
+
+        return Response(True, resp)
\ No newline at end of file
