@@ -44,6 +44,8 @@ from . import utils
 
 LOGGERS = {}
 API_RESOURCE = "https://batchapps.core.windows.net/"
+FILE_LOG = True
+STREAM_LOG = True
 
 class Configuration(object):
     """
@@ -248,12 +250,12 @@ class Configuration(object):
         If an existing log file has exceeded 10mb, it will be 'archived',
         and a new log file created.
 
-        All logging statements will be in the folowing format:
+        All logging statements will be in the following format:
             ``"%(asctime)-15s [%(levelname)s] %(module)s: %(message)s"``
 
         :Args:
             - data_path (str): The path that the log file will be written to
-              if file writting is enabled in the configuration
+              if file writing is enabled in the configuration
               (see :meth:._check_directory())
 
         :Returns:
@@ -271,11 +273,13 @@ class Configuration(object):
             "%(asctime)-15s [%(levelname)s] %(module)s: %(message)s")
 
         logger = logging.getLogger('batch_apps')
-        console_logging = logging.StreamHandler()
-        console_logging.setFormatter(log_format)
-        logger.addHandler(console_logging)
 
-        if self._write_file:
+        if STREAM_LOG:
+            console_logging = logging.StreamHandler()
+            console_logging.setFormatter(log_format)
+            logger.addHandler(console_logging)
+
+        if self._write_file and FILE_LOG:
             logfile = os.path.join(data_path, "batch_apps.log")
 
             if os.path.isfile(logfile) and os.path.getsize(logfile) > 10485760:
@@ -380,6 +384,7 @@ class Configuration(object):
     def set_default_application(self):
         """
         .. warning:: Deprecated. Use :meth:`.set_default_jobtype()`.
+
         Set the job type to be used by default when creating a
         :class:`.Configuration` object. This method will set the current
         job type to be the default, and will save the changes.
@@ -550,6 +555,7 @@ class Configuration(object):
     def application(self, *jobtype):
         """
         .. warning:: Deprecated. Please use :meth:`.current_jobtype()`.
+
         Gets and sets the current job type.
 
         :Args:
@@ -604,6 +610,7 @@ class Configuration(object):
     def applications(self):
         """
         .. warning:: Deprecated. Please use :meth:`.list_jobtypes()`.
+
         Gets a list of all the job types defined in the configuration.
 
         :Returns:
@@ -644,6 +651,7 @@ class Configuration(object):
     def add_application(self, jobtype, *args, **params):
         """
         .. warning:: Deprecated. Please use :meth:`.add_jobtype()`.
+
         Add a new job type section to the configuration.
 
         :Args:
@@ -783,7 +791,7 @@ class Configuration(object):
               from the Batch Apps portal: ``ClientID=abc;TenantID=xyz``.
             - key (str): An Unattended Account key. This can be created in
               the Batch Apps portal.
-            - client_id (str): The client GUID, this can be retrieved from
+            - client_id (str): The client ID, this can be retrieved from
               the AAD portal (not required if using an Unattended Account).
             - tenant (str): The auth tenant, this can be retrieved from
               the AAD portal (not required if using an Unattended Account).
@@ -793,7 +801,7 @@ class Configuration(object):
             - endpoint (str): The Batch Apps service endpoint. This can be
               found in the service details in the Batch Apps Portal.
             - unattended (bool): Whether the intended authentication method
-              will be unattended. Default is ``False``.
+              will be unattended. The default is ``False``.
 
         :Returns:
             - dict containing the authentication parameters.
