@@ -101,9 +101,6 @@ class AzureOAuth(object):
                 redirect_uri=redirect,
                 state=AzureOAuth.state)
 
-        new_session.verify = VERIFY
-        if CA_CERT and VERIFY is True:
-            new_session.verify = CA_CERT
         return new_session
 
     @staticmethod
@@ -125,7 +122,7 @@ class AzureOAuth(object):
 
         :Kwargs:
             - config (:class:`.Configuration`): A custom configuration
-              object. Default is `None` where a default
+              object. The default is `None` in which case a default
               :class:`.Configuration` will be created.
 
         :Returns:
@@ -152,19 +149,19 @@ class AzureOAuth(object):
 
         :Kwargs:
             - config (:class:`.Configuration`): A custom configuration object.
-              Default is `None` where a default :class:`.Configuration` will
-              be created.
-            - msa (bool): Authenticate by MSA. Default is ``False``.
+              The default is `None` in which case a default
+              :class:`.Configuration` will be created.
+            - msa (bool): Authenticate by MSA. The default is ``False``.
             - prompt (bool): Force login prompt regardless of existing session.
-              Default is ``False``.
-            - state (str): A guid for validating the state of the server
+              The default is ``False``.
+            - state (str): An ID for validating the state of the server
               communication.
             - additional_args (dict): Any additional AAD parameters to include
               in the URL
 
         :Returns:
             - A URL (str) that can be used to direct the user to a login page.
-            - A guid (str) for validating the state of the server
+            - A ID (str) for validating the state of the server
               communication.
 
         :Raises:
@@ -209,23 +206,24 @@ class AzureOAuth(object):
 
         except Exception as exp:
             raise AuthenticationException(
-                "Failed to generate auth url. Error: {0}".format(str(exp)))
+                "Failed to generate authentication URL. "
+                "Error: {0}".format(str(exp)))
 
     @staticmethod
     def get_authorization_token(auth_url, config=None, state=None):
         """Retrieve access token from AAD server.
 
         :Args:
-            - auth_url (str): The redirect URL generated from a successfull
+            - auth_url (str): The redirect URL generated from a successful
               browser sign-in.
 
         :Kwargs:
             - config (:class:`.Configuration`): A custom configuration object.
-              Default is `None` where a default :class:`.Configuration` will
-              be created.
-            - state (str): A state guid for auth server validation. This is not
+              The default is `None` in which case a default
+              :class:`.Configuration` will be created.
+            - state (str): A state ID for auth server validation. This is not
               necessary if :meth:`.get_authorization_url` was used to generate
-              the url, as state will already be set. If set, will override.
+              the URL, as state will already be set. If set, will override.
 
         :Returns:
             - An authenticated :class:`.Credentials` object.
@@ -253,6 +251,10 @@ class AzureOAuth(object):
             raise AuthenticationException(
                 "Security error: State not equal in request and response.")
 
+        verification = VERIFY
+        if CA_CERT and VERIFY is True:
+            verification = CA_CERT
+
         redirect = auth.get('redirect_uri')
 
         if auth_url.startswith(_http(redirect)):
@@ -267,7 +269,8 @@ class AzureOAuth(object):
                                  "{0}".format(token_uri))
 
             token = session.fetch_token(token_uri,
-                authorization_response=auth_url)
+                authorization_response=auth_url,
+                verify=verification)
 
         except oauth2.rfc6749.errors.InvalidGrantError as excp:
             raise AuthenticationException(excp.description)
@@ -285,12 +288,13 @@ class AzureOAuth(object):
     def get_principal_token(config=None):
         """
         .. warning:: Deprecated. Please use :meth:`.get_unattended_session()`.
+
         Retrieve a Unattended Account access token from AAD server.
 
         :Kwargs:
             - config (:class:`.Configuration`): A custom configuration object.
-              Default is `None` where a default :class:`.Configuration`
-              will be created.
+              The default is `None` in which case a default
+              :class:`.Configuration` will be created.
 
         :Returns:
             - An authenticated :class:`.Credentials` object.
@@ -312,8 +316,8 @@ class AzureOAuth(object):
 
         :Kwargs:
             - config (:class:`.Configuration`): A custom configuration object.
-              Default is `None` where a default :class:`.Configuration`
-              will be created.
+              The default is `None` in which case a default
+              :class:`.Configuration` will be created.
 
         :Returns:
             - An authenticated :class:`.Credentials` object.
