@@ -90,6 +90,7 @@ class FileManager(object):
     def create_file(self, fullpath):
         """
         .. warning:: Deprecated. Use :meth:`.file_from_path()`.
+
         Create a userfile object.
 
         :Args:
@@ -128,7 +129,7 @@ class FileManager(object):
 
         :Kwargs:
             - recursive (bool): Whether the set will include the contents of
-              subdirectories. Default is ``False``
+              subdirectories. The default is ``False``
             - pattern (str): The pattern to apply to filter director contents.
               Default: ``"*"``, i.e. all files included.
 
