@@ -40,10 +40,10 @@ from .exceptions import (
     RestCallException)
 
 def upload_wrapper(arg, **kwargs):
-    '''
+    """
     Wrapper to pull upload method from self to avoid multiprocessing
     errors in Python 2.6.
-    '''
+    """
     return FileCollection._upload_forced(*arg, **kwargs)
 
 
@@ -55,12 +55,15 @@ class FileCollection(object):
 
     def __init__(self, client, *files):
         """
+        Create new FileCollection:
+
         :Args:
             - client (:class:`.BatchAppsApi`): An authorized Batch Apps
               Management API REST client.
             - files (:class:`UserFile`, list): *Optional*. Any files to be
               included in the collection. Can be individual
               :class:`UserFile` objects or a list of them.
+
         """
         if not hasattr(client, 'query_files'):
             raise TypeError(
@@ -112,7 +115,7 @@ class FileCollection(object):
 
         :Returns:
             - If a string name is passed in, the output will be a list of
-              :class:`.UserFile` objects, as multplie files may have the same
+              :class:`.UserFile` objects, as multiple files may have the same
               name. Likewise, passing in a slice will produce a list of
               :class:`.UserFile`. Passing an int index will return a single
               :class:`.UserFile`
@@ -317,8 +320,8 @@ class FileCollection(object):
         :Args:
             - userfile (str, int, :class:`.UserFile`, list, slice): The name,
               object or index of the file to be removed. If a name is passed
-              in, only the first occurance of that name will be removed. To
-              remove all occurances, use :meth:`.__delitem__()`.
+              in, only the first occurrence of that name will be removed. To
+              remove all occurrences, use :meth:`.__delitem__()`.
               A :class:`.UserFile` object can also be passed in or a list
               of any of the above.
 
@@ -364,11 +367,10 @@ class FileCollection(object):
         """Upload all files in a set, optionally in parallel
 
         :Kwargs:
-            - force (bool): Whether the client will only upload if the file
-              has not be previously uploaded. Default is ``False``,
-              i.e. always check and if file has been uploaded, don't
-              re-uplod. Set to ``True`` to upload regardless.
-            - threads (int): number of parallel uploads, default is 1
+            - force (bool): If ``True``, uploads regardless of whether the
+              file has already been uploaded. Otherwise checks if file has
+              been uploaded, and if so, skips. The default is ``False``.
+            - threads (int): Maximum number of parallel uploads, default is 1
               (i.e. not parallel). Max threads is 10.
 
         :Returns:
@@ -442,7 +444,8 @@ class FileCollection(object):
             - per_call (int): Number of files to check against the server
               at a time. The more per call, the slower the call and the
               bigger the return object, but too few per call could mean a
-              large number of calls for a big file collection. Default is 50.
+              large number of calls for a big file collection. The default
+              is 50.
 
         :Returns:
             - An :class:`FileCollection` containing the files that have yet
@@ -480,7 +483,7 @@ class FileCollection(object):
                              if (_file.name == r_file.name)
                              and (_file.compare_lastmodified(r_file))]
 
-                # Remove any matches from the list of files to be uplaoded.
+                # Remove any matches from the list of files to be uploaded.
                 file_set.remove(to_remove)
 
         self._log.debug(
@@ -503,6 +506,8 @@ class UserFile(object):
 
     def __init__(self, client, file_def):
         """
+        Create new UserFile:
+
         :Args:
             - client (:class:`BatchAppsApi`): Authenticated and configured
               REST API client.
@@ -619,7 +624,7 @@ class UserFile(object):
         return self.name
 
     def __hash__(self):
-        """:class:`.UserFile` hashing behaviour
+        """:class:`.UserFile` hashing behavior
 
         :Returns:
             - If file exists locally, hash of the file checksum.
@@ -633,14 +638,14 @@ class UserFile(object):
             return hash(self.path)
 
     def _verify_path(self):
-        """Verify existance of new userfile reference.
+        """Verify existence of new userfile reference.
 
         :Returns:
             - ``True`` if file exists at the given path, else ``False``.
         """
         if not path.isfile(self.path):
             self._log.warning(
-                "Unable to verify existance of new file: %s", self.path)
+                "Unable to verify existence of new file: %s", self.path)
 
             return False
 
@@ -775,8 +780,8 @@ class UserFile(object):
 
         :Kwargs:
             - force (bool): If ``True``, uploads regardless of whether the
-              file has already been uploaded. Else, checks if file has been
-              uploaded, and if so, skips.
+              file has already been uploaded. Otherwise checks if file has
+              been uploaded, and if so, skips. The default is ``False``.
 
         :Returns:
             - Client :class:`.Response` object if upload was attempted.
@@ -804,8 +809,8 @@ class UserFile(object):
             - :class:`.UserFile` if file has already been uploaded, else ``None``.
 
         :Raises:
-            - :class:`.RestCallException` if any errors occured in the API
-              client.
+            - :class:`.RestCallException` if an error occurred during the
+              request.
         """
         resp = self._api.query_files(self.create_query_specifier())
         if resp.success:
@@ -832,8 +837,8 @@ class UserFile(object):
               will be downloaded.
 
         :Raises:
-            - :class:`.RestCallException` if any errors occured in the API
-              client.
+            - :class:`.RestCallException` if an error occurred during the
+              request.
         """
         
         try:
