@@ -27,6 +27,7 @@
 
 from batchapps.exceptions import FileDownloadException
 from batchapps import utils
+from batchapps.pool import PoolSpecifier
 from batchapps.utils import Listener
 from batchapps.files import (
     UserFile,
@@ -46,7 +47,7 @@ class JobSubmission(object):
     Description of a new processing request to be sent to the cloud.
     Specifies application to be used, the files required for processing and
     any additional parameters required for the processing.
-    It also specifies the requested compute resouces to be dedicated to the
+    It also specifies the requested compute resources to be dedicated to the
     job on submission.
 
     :Attributes:
@@ -54,6 +55,7 @@ class JobSubmission(object):
         - required_files (:py:class:`.FileCollection`)
         - source (str)
         - instances (int)
+        - pool (:py:class:`.Pool`)
         - params (dict)
     """
 
@@ -67,6 +69,7 @@ class JobSubmission(object):
         :Kwargs:
             - job_settings (dict): *Optional* Additional job settings or
               parameters can be added as keyword arguments. These include:
+
                   - 'params': A string dict of job parameters to add to the
                     submission.
                   - 'files': A :py:class:`.FileCollection` of required files
@@ -76,6 +79,8 @@ class JobSubmission(object):
                     included in the above ``files`` collection.
                   - 'instances': The number (int) of instances to allocate
                     to the job on submission.
+                  - 'pool': A :py:class:`.Pool` to submit the job to. Default
+                    is ``None``, i.e. create an auto-pool.
         """
         if not hasattr(client, 'send_job'):
             raise TypeError(
@@ -95,7 +100,9 @@ class JobSubmission(object):
         super(JobSubmission, self).__setattr__(
             'source', str(job_settings.get('job_file', "")))
         super(JobSubmission, self).__setattr__(
-            'instances', int(job_settings.get('instances', 0)))
+            'instances', int(job_settings.get('instances', 0))) #DEP
+        super(JobSubmission, self).__setattr__(
+            'pool', job_settings.get('pool', None))
 
     def __str__(self):
         """Job submission as a string
@@ -107,7 +114,7 @@ class JobSubmission(object):
 
     def __getattr__(self, name):
         """
-        Get job attribute, or job parameter.
+        Get a job attribute, or a job parameter.
         This will only be called if :py:class:`.JobSubmission` object does
         not have the requested attribute, in which case the job parameters
         dictionary will be searched for a matching key.
@@ -131,7 +138,7 @@ class JobSubmission(object):
 
     def __setattr__(self, name, value):
         """
-        Set job attribte if it exists, or add job parameter.
+        Set a job attribute if it exists, or add a job parameter.
         If the :py:class:`.JobSubmission` object has the named attribute
         this will be set. If no such attribute exists, the key and value will
         be added as a string pair to the job parameters dictionary.
@@ -191,9 +198,26 @@ class JobSubmission(object):
 
         return utils.format_dictionary(complete_params)
 
+    def _auto_pool(self, size):
+        """
+        Create an autopoolspecification reference for use in job
+        submission.
+
+        :Returns:
+            - A dictionary.
+        """
+        pool = PoolSpecifier(self._api, target_size=size)
+
+        return {
+            'targetDedicated': str(pool.target_size),
+            'maxTasksPerTVM': str(pool.max_tasks),
+            'communication': pool.communication,
+            'certificateReferences': pool.certificates
+            }
+
     def _create_job_message(self):
         """
-        Create job message for submitting to the REST API.
+        Create a job message for submitting to the REST API.
         Only used internally on job submission (see :py:meth:.submit()).
 
         :Returns:
@@ -205,16 +229,26 @@ class JobSubmission(object):
         if not hasattr(self.required_files, '_get_message'):
             self.add_file_collection()
 
+        if self.pool and hasattr(self.pool, 'id'):
+            pool_options = {'poolId': self.pool.id}
+
+        elif self.pool:
+            pool_options = {'poolId': str(self.pool)}
+
+        else:
+            size = max(int(self.instances), 3)
+            pool_options = {'autoPoolSpecification': self._auto_pool(size)}
+
         job_message = {
             'Name': str(self.name),
             'Type': self._api.jobtype(),
             'RequiredFiles': self.required_files._get_message("submit"),
-            'Pool': {'InstanceCount': str(int(self.instances))},
             'Parameters': list(self._filter_params()),
             'JobFile': str(self.source),
             'Settings': '',
             'Priority': 'Medium'
         }
+        job_message.update(pool_options)
 
         self._log.debug("Job message: {0}".format(job_message))
         return job_message
@@ -271,6 +305,7 @@ class JobSubmission(object):
         """
         if self.required_files is None:
             self.required_files = FileCollection(self._api)
+
         self.required_files.add(userfile)
 
     def set_job_file(self, jobfile):
@@ -319,16 +354,20 @@ class JobSubmission(object):
               to get the job details (See: :meth:`.SubmittedJob.update()`).
               Dictionary has the keys: ``['jobId', 'link']``
 
+              .. warning:: 'jobId' key will be deprecated to be replaced with 'id'.
+
         :Raises:
             - :class:`.RestCallException` if job submission failed.
         """
         resp = self._api.send_job(self._create_job_message())
-
+        
         if resp.success:
-            self._log.info("Job successfull submitted with ID: "
+            self._log.info("Job successfully submitted with ID: "
                            "{0}".format(resp.result['jobId']))
 
-            return resp.result
+            return {'jobId':resp.result['jobId'], #DEP
+                    'id': resp.result['jobId'],
+                    'link': resp.result['link']['href']}
 
         else:
             raise resp.result
@@ -355,6 +394,7 @@ class SubmittedJob(object):
         - output_url (str)
         - thumb_url (str)
         - tasks_url (str)
+        - pool_id (str)
     """
 
     def __init__(self, client, job_id, job_name, job_type, **job_settings):
@@ -433,13 +473,13 @@ class SubmittedJob(object):
 
     def __setattr__(self, name, value):
         """
-        Set job attribte if it exists.
+        Set a job attribute if it exists.
         The submission data cannot be overwritten except through using the
         :meth:`.update()` call to collect updated date from the server.
 
         :Args:
-            - name (str): Name of the attribte to be set.
-            - value: Value to set to the attribute.
+            - name (str): Name of the attribute to be set.
+            - value: Value of the attribute.
 
         :Raises:
             - :exc:`ValueError` if attempts to overwrite submission data.
@@ -501,13 +541,13 @@ class SubmittedJob(object):
         formatted['time_submitted'] = sub.get('submissionTime', None)
         formatted['time_started'] = sub.get('startTime', None)
         formatted['time_completed'] = sub.get('completionTime', None)
-        #formatted['requested_instances'] = sub.get('pool', {'instanceCount':0})['instanceCount']
-        formatted['requested_instances'] = int(sub.get('instanceCount', 0))
+        formatted['requested_instances'] = int(sub.get('instanceCount', 0)) #DEP
         formatted['number_tasks'] = int(sub.get('taskCount', 0))
         formatted['output_filename'] = sub.get('outputFileName', None)
         formatted['output_url'] = sub.get('outputLink', {'href':None})['href']
         formatted['thumb_url'] = sub.get('previewLink', {'href':None})['href']
         formatted['tasks_url'] = sub.get('taskListLink', {'href':None})['href']
+        formatted['pool_id'] = sub.get('poolId', None)
 
         self._log.debug("Extracted job submission data: {0}".format(formatted))
         return formatted
@@ -573,7 +613,7 @@ class SubmittedJob(object):
         """Internal method to download any file from the job output.
 
         :Args:
-            - output (dict): The output specification dictonary as created
+            - output (dict): The output specification dictionary as created
               by :meth:`.list_all_outputs()`.
             - download_dir (str): The directory the output file will be
               written to.
@@ -590,7 +630,7 @@ class SubmittedJob(object):
         output_props = self._api.props_output_file(url=output.get('link'))
 
         if output_props.success:
-            self._log.debug("Successfull retrieved output size data: "
+            self._log.debug("Successfully retrieved output size data: "
                             "{0}".format(output_props.result))
 
             size = output_props.result
@@ -647,7 +687,7 @@ class SubmittedJob(object):
         :Kwargs:
             - output: An output dictionary (as created by
               :meth:`.list_all_outputs()`). If specified, the specific output
-              will be downloaded, otheriwse the jobs final output will be
+              will be downloaded, otherwise the job's final output will be
               downloaded.
 
         :Returns:
@@ -657,7 +697,7 @@ class SubmittedJob(object):
             - :exc:`.FileDownloadException` if the SubmittedJob has no URL
               to a final output yet. This may be because the job has not yet
               finished, or has not been updated.
-            - :exc:`.RestCallException` if an error occured during the request.
+            - :exc:`.RestCallException` if an error occurred during the request.
         """
         if output:
             name = output.get('name', "")
@@ -690,7 +730,8 @@ class SubmittedJob(object):
               ``['name', 'link', 'type']``.
 
         :Raises:
-            - :exc:`.RestCallException` if error occured during request.
+            - :exc:`.RestCallException` if an error occurred during the
+              request.
         """
         all_outputs = self._api.list_output_files(self.id)
 
@@ -712,7 +753,7 @@ class SubmittedJob(object):
             - filename (str): A name to give the thumbnail file. If not
               specified a randomly generated filename will be used.
             - overwrite (bool): Whether an existing file will be overwritten.
-              Default is ``True``.
+              The default is ``True``.
 
         :Returns:
             - The full path to the downloaded file (str).
@@ -721,7 +762,7 @@ class SubmittedJob(object):
             - :exc:`.FileDownloadException` if the SubmittedJob has no
               reference to a job thumbnail. This could mean that the job
               has not yet completed or the object has not been updated.
-            - :exc:`.RestCallException` if an error occured during the request.
+            - :exc:`.RestCallException` if an error occurred during the request.
         """
         if not download_dir:
             download_dir = tempfile.gettempdir()
@@ -752,9 +793,9 @@ class SubmittedJob(object):
         :Kwargs:
             - start (str): The UTC time from which log messages will be
               retrieved. If not set, will retrieve messages from the start
-              of the job. Default is ``None``.
+              of the job. The default is ``None``.
             - max_lines (int): The max number of log messages to be retrieved.
-              Default is 100.
+              The default is 100.
 
         :Returns:
             - If successful, a dict in the format:
@@ -785,7 +826,7 @@ class SubmittedJob(object):
             - ``True`` if the job has been successfully updated.
 
         :Raises:
-            - :exc:`.RestCallException` if an error occured during the request.
+            - :exc:`.RestCallException` if an error occurred during the request.
         """
         self._log.debug("About to update job {0}".format(self.id))
         resp = self._api.get_job(self.id)
@@ -829,8 +870,8 @@ class SubmittedJob(object):
         Reprocess any failed tasks in a job.
 
         :Returns:
-            - ``True`` if the failed tasks have been successfully requeued.
-            - ``False`` if the job is unable to be requeued,
+            - ``True`` if the failed tasks have been successfully re-queued.
+            - ``False`` if the job is unable to be re-queued,
               e.g. it has already completed.
 
         :Raises:
@@ -953,7 +994,7 @@ class Task(object):
               specified and one has not been specified by the server, a
               randomly generated filename will be used.
             - overwrite (bool): Whether an existing file will be overwritten.
-              Default is ``True``.
+              The default is ``True``.
 
         :Returns:
             - The full path to the downloaded file (str).
@@ -961,8 +1002,8 @@ class Task(object):
         :Raises:
             - :exc:`.FileDownloadException` if the Task has no reference to
               a thumbnail. This could mean that the task has not yet
-              completed or the object has not been updated.
-            - :exc:`.RestCallException` if an error occured during the request.
+              completed or that the object has not been updated.
+            - :exc:`.RestCallException` if an error occurred during the request.
         """
         if not download_dir:
             download_dir = tempfile.gettempdir()
@@ -1005,7 +1046,8 @@ class Task(object):
               ``['name', 'link', 'type']``.
 
         :Raises:
-            - :exc:`.RestCallException` if error occured during request.
+            - :exc:`.RestCallException` if an error occurred during the
+              request.
         """
         resp = self._api.list_task_outputs(self._job, self.id)
 
@@ -1027,13 +1069,13 @@ class Task(object):
 
         :Kwargs:
             - overwrite (bool): Whether to overwrite an existing file.
-              Default is ``False``.
+              The default is ``False``.
 
         :Returns:
             - The full path to the downloaded file (str).
 
         :Raises:
-            - :exc:`.RestCallException` if an error occured during the request.
+            - :exc:`.RestCallException` if an error occurred during the request.
         """
         download = self._get_file(output, download_dir, overwrite)
         if download.success:
