@@ -37,8 +37,8 @@ from .exceptions import RestCallException
 class JobManager(object):
     """
     This is the only class that a user should need to import to access all
-    job manipulation. Contains general functionality for the creation
-    of new job submissions and retrieveing data on submitted jobs.
+    job manipulation. It contains general functionality for the creation
+    of new job submissions and retrieving data on submitted jobs.
     """
 
     def __init__(self, credentials, cfg=None):
@@ -75,15 +75,15 @@ class JobManager(object):
             - job (:class:`.SubmittedJob`): A job object to be updated.
             - url (str): The URL to a the details of a job, as returned by
               :meth:`.JobSubmission.submit()`.
-            - jobid (str): The ID of a submitted job, as retrieved from
-              Mission Control or returned by :meth:`.JobSubmission.submit()`.
+            - jobid (str): The ID of a submitted job, as retrieved from the
+              Management Portal or returned by :meth:`.JobSubmission.submit()`.
 
         :Returns:
             - An updated or new :class:`.SubmittedJob` object.
 
         :Raises:
             - :exc:`AttributeError` if invalid parameters have been set.
-            - :exc:`.RestCallException` if an error occured during the request.
+            - :exc:`.RestCallException` if an error occurred during the request.
         """
         resp = None
         if hasattr(job, 'update'):
@@ -118,15 +118,15 @@ class JobManager(object):
 
         :Kwargs:
             - index (int): The start index of the list of jobs to be returned.
-              Default is 0, i.e. return all jobs from the beginning.
-            - per_call (int): Number of jobs to be returned. Default is 10.
+              The default is 0, i.e. return all jobs from the beginning.
+            - per_call (int): Number of jobs to be returned. The default is 10.
             - name (str): Only return jobs whose names contain this string.
 
         :Returns:
             - A list of :class:`.SubmittedJob` objects.
 
         :Raises:
-            - :exc:`.RestCallException` if an error occured during the request.
+            - :exc:`.RestCallException` if an error occurred during the request.
         """
         if name:
             resp = self._client.list_jobs(int(index),
@@ -166,6 +166,7 @@ class JobManager(object):
         :Kwargs:
             - jobdetails (dict): Additional job settings or parameters can be
               added as keyword arguments. These include:
+
                 - 'params': A string dict of job parameters to add to the
                   submission.
                 - 'files': A :class:`.FileCollection` of required files to
@@ -188,13 +189,16 @@ class JobManager(object):
             - submitjob (:class:`.JobSubmission`): The job to be submitted.
 
         :Kwargs:
-            - upload_threads (int): Number of concurrent asset uplaods.
-              Default is 1.
+            - upload_threads (int): Maximum number of concurrent asset uploads.
+              The default is 1.
 
         :Returns:
-            - A job susbmission response dictionary in the format:
+            - A job submission response dictionary in the format:
               ``{'jobId': '', 'link': ''}``
 
+              .. warning:: Dictionary response will be deprecated to be replaced
+                 by a :class:`.SubmittedJob` object in 1.0 release.
+
         :Raises:
             - :exc:`TypeError` if ``submitjob`` is not a JobSubmission.
             - :exc:`.RestCallException` if job submission failed.
