@@ -61,7 +61,8 @@ def _call(auth, *args, **kwargs):
 
         resp = conn_session.request(*args, **kwargs)
 
-    except oauth2.rfc6749.errors.InvalidGrantError as exp:
+    except (oauth2.rfc6749.errors.InvalidGrantError,
+            oauth2.rfc6749.errors.TokenExpiredError) as exp:
         auth.clear_auth()
         raise SessionExpiredException("Please log in again. "
                                       "{0}".format(str(exp)))
@@ -109,8 +110,8 @@ def _call(auth, *args, **kwargs):
             raise  RestCallException(None, msg, resp, silent=True)
 
         elif resp.status_code == 404:
-            msg = ("Invalid endpoint or api call. Failed with status {0}.\n"
-                   "Url: {1}".format(resp.status_code, resp.url))
+            msg = ("Invalid endpoint or API call. Failed with status {0}.\n"
+                   "URL: {1}".format(resp.status_code, resp.url))
             raise RestCallException(OSError, msg, resp)
 
         else:
@@ -123,11 +124,12 @@ def get(auth, url, headers, params=None):
     Call GET.
 
     :Args:
+        - auth (:class:`.Credentials`): The session credentials object.
         - url (str): The complete endpoint URL.
         - headers (dict): The headers to be used in the request.
 
     :Kwargs:
-        - params (dict): Any additional parameters to be added to the uri as
+        - params (dict): Any additional parameters to be added to the URI as
           required by the specified call.
 
     :Returns:
@@ -137,7 +139,7 @@ def get(auth, url, headers, params=None):
         - :exc:`.RestCallException` is the call failed,
           or returned a non-200 status.
     """
-    LOG.debug("Get call url: {0}, headers: {1}, params: "
+    LOG.debug("Get call URL: {0}, headers: {1}, params: "
               "{2}".format(url, headers, params))
 
     try:
@@ -160,12 +162,13 @@ def head(auth, url, headers, filename=""):
     header to get a file size.
 
     :Args:
+        - auth (:class:`.Credentials`): The session credentials object.
         - url (str): The complete endpoint URL.
         - headers (dict): The headers to be used in the request.
 
     :Kwargs:
         - filename (str): Used to add a filename to the end of the URL if
-          doesn't already have one. Default is an empty string.
+          doesn't already have one. The default is an empty string.
 
     :Returns:
         - The content-length header, as an integer.
@@ -176,7 +179,7 @@ def head(auth, url, headers, filename=""):
     """
     try:
         url = url.format(name=url_from_filename(filename))
-        LOG.debug("Head call url: {0}, headers: {1}".format(url, headers))
+        LOG.debug("Head call URL: {0}, headers: {1}".format(url, headers))
         response = _call(auth, 'HEAD', url, headers=headers)
         return int(response.headers["content-length"])
 
@@ -190,7 +193,7 @@ def head(auth, url, headers, filename=""):
 
     except IndexError as exp:
         raise RestCallException(IndexError,
-                                "Incorrectly formatted url supplied.",
+                                "Incorrectly formatted URL supplied.",
                                 exp)
 
 def post(auth, url, headers, message=None):
@@ -199,12 +202,13 @@ def post(auth, url, headers, message=None):
     Used for job submission, job commands and file queries.
 
     :Args:
+        - auth (:class:`.Credentials`): The session credentials object.
         - url (str): The complete endpoint URL.
         - headers (dict): The headers to be used in the request.
 
     :Kwargs:
         - message (dict): Data to be acted on e.g. job submission
-          specfication, file query parameters. Format and contents will
+          specification, file query parameters. The format and contents will
           depend on the specific API call.
 
     :Returns:
@@ -218,7 +222,7 @@ def post(auth, url, headers, message=None):
         if message:
             message = json.dumps(message)
 
-        LOG.debug("Post call url: {0}, headers: {1}, message: "
+        LOG.debug("Post call URL: {0}, headers: {1}, message: "
                   "{2}".format(url, headers, message))
 
         response = _call(auth, 'POST', url, headers=headers, data=message)
@@ -243,6 +247,7 @@ def put(auth, url, headers, userfile, params, *args):
     This call is only used to upload files.
 
     :Args:
+        - auth (:class:`.Credentials`): The session credentials object.
         - url (str): The complete endpoint URL.
         - headers (dict): The headers to be used in the request.
         - userfile (:class:`.UserFile`): The :class:`.UserFile`
@@ -262,8 +267,7 @@ def put(auth, url, headers, userfile, params, *args):
         put_headers = dict(headers)
         put_headers["Content-Type"] = "application/octet-stream"
 
-        LOG.info("url={0}, headers={1}".format(url, put_headers))
-        LOG.debug("Put call url: {0}, headers: {1}, "
+        LOG.debug("Put call URL: {0}, headers: {1}, "
                   "file: {2}, parameters: {3}".format(url,
                                                       put_headers,
                                                       userfile,
@@ -288,7 +292,7 @@ def put(auth, url, headers, userfile, params, *args):
 
     except IndexError as exp:
         raise RestCallException(IndexError,
-                                "Incorrectly formatted url supplied.",
+                                "Incorrectly formatted URL supplied.",
                                 exp)
 
 def download(auth, url, headers, output_path, size, overwrite,
@@ -299,6 +303,7 @@ def download(auth, url, headers, output_path, size, overwrite,
     Call GET for a file stream.
 
     :Args:
+        - auth (:class:`.Credentials`): The session credentials object.
         - url (str): The complete endpoint URL.
         - headers (dict): The headers to be used in the request.
         - output_path (str): Full file path to download the data to.
@@ -309,11 +314,11 @@ def download(auth, url, headers, output_path, size, overwrite,
 
     :Kwargs:
         - f_name (str): Used to specify a filename if one is not already
-          included in the URL. Default is ``None``.
+          included in the URL. The default is ``None``.
         - ext (str): Used to specify a file extension if one is not already
-          included in the URL. Default is ``None``.
+          included in the URL. The default is ``None``.
         - block_size (int): Used to vary the upload chunk size.
-          Default is 1024 bytes.
+          The default is 1024 bytes.
 
     :Returns:
         - The raw server response.
@@ -331,7 +336,7 @@ def download(auth, url, headers, output_path, size, overwrite,
 
         return True
 
-    LOG.debug("Get call url: {0}, headers: {1}, file: "
+    LOG.debug("Get call URL: {0}, headers: {1}, file: "
               "{2}, size: {3}, overwrite: {4}".format(url,
                                                       headers,
                                                       downloadfile,
@@ -368,3 +373,34 @@ def download(auth, url, headers, output_path, size, overwrite,
 
     except EnvironmentError as exp:
         raise RestCallException(type(exp), str(exp), exp)
+ 
+def delete(auth, url, headers):
+    """
+    Call DELETE.
+    Currently only used to delete pools.
+
+    :Args:
+        - auth (:class:`.Credentials`): The session credentials object.
+        - url (str): The complete endpoint URL.
+        - headers (dict): The headers to be used in the request.
+
+    :Returns:
+        - The raw server response.
+
+    :Raises:
+        - :exc:`.RestCallException` if the call failed or returned a
+          non-200 status.
+    """
+    try:
+        LOG.debug("Delete call URL: {0}".format(url))
+        response = _call(auth, 'DELETE', url, headers=headers)
+        return response
+
+    except RestCallException:
+        raise
+
+    except (ValueError, AttributeError) as exp:
+        raise RestCallException(
+            ValueError,
+            "No json object to be decoded from DELETE call.",
+            exp)
\ No newline at end of file
