@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------
-# The Azure Batch Apps Python Client ver. 0.1.0
+# The Azure Batch Apps Python Client
 #
 # Copyright (c) Microsoft Corporation. All rights reserved. 
 #
@@ -133,15 +133,17 @@ class TestConfiguration(unittest.TestCase):
         cfg = Configuration(data_path=self.test_dir, application='Blender')
         self.assertTrue(mock_save.called)
         self.assertTrue(mock_read.called)
+        self.assertEqual(cfg.jobtype, "Blender")
         self.assertEqual(cfg.job_type, "Blender")
 
-        cfg = Configuration(data_path=self.test_dir, application=None)
+        cfg = Configuration(data_path=self.test_dir, jobtype=None)
+        self.assertEqual(cfg.jobtype, "Blender")
         self.assertEqual(cfg.job_type, "Blender")
 
         with self.assertRaises(InvalidConfigException):
             Configuration(application='TestApp', default=True)
         with self.assertRaises(InvalidConfigException):
-            Configuration(application=42, default=True)
+            Configuration(jobtype=42, default=True)
 
     @mock.patch.object(Configuration, '_check_directory')
     @mock.patch.object(Configuration, '_configure_logging')
@@ -167,7 +169,7 @@ class TestConfiguration(unittest.TestCase):
         mock_file.assert_called_with(
             os.path.join(self.test_dir, "batch_apps.ini"))
 
-        self.assertEqual(cfg.job_type, "Blender")
+        self.assertEqual(cfg.jobtype, "Blender")
 
     @mock.patch.object(batchapps.config.os.path, 'isdir')
     @mock.patch.object(batchapps.config.os, 'mkdir')
@@ -337,7 +339,16 @@ class TestConfiguration(unittest.TestCase):
 
     @mock.patch.object(Configuration, 'save_config')
     def test_config_set_default_application(self, mock_save):
-        """Test set_default_application"""
+        """Test deprecated method set_default_application"""
+
+        cfg = mock.create_autospec(Configuration)
+        cfg._log = logging.getLogger("set_default_application")
+        Configuration.set_default_application(cfg)
+        self.assertTrue(cfg.set_default_jobtype.called)
+
+    @mock.patch.object(Configuration, 'save_config')
+    def test_config_set_default_jobtype(self, mock_save):
+        """Test set_default_jobtype"""
 
         if not self.use_test_files:
             self.skipTest("No test files present")
@@ -346,17 +357,18 @@ class TestConfiguration(unittest.TestCase):
         _cfg.read(os.path.join(self.test_dir, "batch_apps.ini"))
         cfg = mock.create_autospec(Configuration)
         cfg._config = _cfg
-        cfg.job_type = "Test"
+        cfg.jobtype = "Test"
         cfg._write_file = True
+        cfg._log = logging.getLogger("set_default_jobtype")
 
-        Configuration.set_default_application(cfg)
-        self.assertFalse(cfg._config.has_option('Blender', 'default_app'))
-        self.assertTrue(cfg._config.has_option('Test', 'default_app'))
+        Configuration.set_default_jobtype(cfg)
+        self.assertFalse(cfg._config.has_option('Blender', 'default_jobtype'))
+        self.assertTrue(cfg._config.has_option('Test', 'default_jobtype'))
 
-        cfg.job_type = "Test"
-        Configuration.set_default_application(cfg)
-        self.assertFalse(cfg._config.has_option('Blender', 'default_app'))
-        self.assertTrue(cfg._config.has_option('Test', 'default_app'))
+        cfg.jobtype = "Test"
+        Configuration.set_default_jobtype(cfg)
+        self.assertFalse(cfg._config.has_option('Blender', 'default_jobtype'))
+        self.assertTrue(cfg._config.has_option('Test', 'default_jobtype'))
 
     @mock.patch(BUILTIN_OPEN)
     def test_config_save_config(self, mock_open):
@@ -408,20 +420,23 @@ class TestConfiguration(unittest.TestCase):
         cfg = mock.create_autospec(Configuration)
         cfg._log = logging.getLogger("endpoint")
         cfg._config = _cfg
-        cfg.job_type = "SomeApp"
+        cfg.jobtype = "SomeApp"
 
         with self.assertRaises(InvalidConfigException):
             Configuration.endpoint(cfg)
-        with self.assertRaises(InvalidConfigException):
-            Configuration.endpoint(cfg, "test")
 
-        cfg.job_type = "TestApp"
+        _cfg.add_section('Authentication')
+        with self.assertRaises(InvalidConfigException):
+            Configuration.endpoint(cfg)
+
+        cfg.jobtype = "TestApp"
         ept = Configuration.endpoint(cfg)
         self.assertEqual(_cfg.get('TestApp', 'endpoint'), 'http://test')
         self.assertEqual(ept, 'test')
 
         ept = Configuration.endpoint(cfg, "https://new_test/")
-        self.assertEqual(_cfg.get('TestApp', 'endpoint'), 'https://new_test/')
+        self.assertEqual(_cfg.get('TestApp', 'endpoint'), 'http://test')
+        self.assertEqual(_cfg.get('Authentication', 'endpoint'), 'https://new_test/')
         self.assertEqual(ept, 'new_test/')
 
     def test_config_logging_level(self):
@@ -447,40 +462,62 @@ class TestConfiguration(unittest.TestCase):
         cfg._set_logging_level.assert_called_with("warning")
 
     def test_config_application(self):
-        """Test application"""
+        """Test depcrecated method application"""
+        cfg = mock.create_autospec(Configuration)
+        cfg._log = logging.getLogger("application")
+        Configuration.application(cfg)
+        self.assertTrue(cfg.current_jobtype.called)
+
+        Configuration.application(cfg, "test")
+        cfg.current_jobtype.assert_called_with("test")
+
+    def test_config_current_jobtype(self):
+        """Test current_jobtype"""
 
         _cfg = configparser.RawConfigParser()
         cfg = mock.create_autospec(Configuration)
-        cfg._log = logging.getLogger("application")
+        cfg._log = logging.getLogger("jobtype")
         cfg._config = _cfg
-        cfg.job_type = "TestApp"
+        cfg.jobtype = "TestApp"
 
-        app = Configuration.application(cfg)
-        self.assertEqual(app, cfg.job_type)
+        app = Configuration.current_jobtype(cfg)
+        self.assertEqual(app, cfg.jobtype)
 
         _cfg.add_section('TestApp2')
         with self.assertRaises(InvalidConfigException):
-            Configuration.application(cfg, 'DifferentApp')
+            Configuration.current_jobtype(cfg, 'DifferentApp')
 
-        app = Configuration.application(cfg, "TestApp2")
+        app = Configuration.current_jobtype(cfg, "TestApp2")
         self.assertEqual(app, 'TestApp2')
+        self.assertEqual(cfg.jobtype, 'TestApp2')
         self.assertEqual(cfg.job_type, 'TestApp2')
 
     def test_config_applications(self):
-        """Test applications"""
+        """Test deprecated method applications"""
+        cfg = mock.create_autospec(Configuration)
+        cfg._log = logging.getLogger("applications")
+        Configuration.applications(cfg)
+        self.assertTrue(cfg.list_jobtypes.called)
+
+    def test_config_list_jobtypes(self):
+        """Test list_jobtypes"""
 
         _cfg = configparser.RawConfigParser()
         _cfg.add_section("Logging")
         cfg = mock.create_autospec(Configuration)
-        cfg._log = logging.getLogger("applications")
+        cfg._log = logging.getLogger("list_jobtypes")
         cfg._config = _cfg
 
-        apps = Configuration.applications(cfg)
+        with self.assertRaises(InvalidConfigException):
+            apps = Configuration.list_jobtypes(cfg)
+
+        _cfg.add_section("Authentication")
+        apps = Configuration.list_jobtypes(cfg)
         self.assertEqual(apps, [])
 
         _cfg.add_section("Blender")
         _cfg.add_section("NewTestApp")
-        apps = Configuration.applications(cfg)
+        apps = Configuration.list_jobtypes(cfg)
         self.assertEqual(sorted(apps), sorted(['Blender', 'NewTestApp']))
 
     def test_config_default_params(self):
@@ -491,7 +528,7 @@ class TestConfiguration(unittest.TestCase):
         cfg = mock.create_autospec(Configuration)
         cfg._log = logging.getLogger("default_params")
         cfg._config = _cfg
-        cfg.job_type = "TestApp"
+        cfg.jobtype = "TestApp"
 
         params = Configuration.default_params(cfg)
         self.assertEqual(params, {})
@@ -504,34 +541,35 @@ class TestConfiguration(unittest.TestCase):
         self.assertEqual(params, {'1':'teST', '2':None, '3':[]})
 
     def test_config_add_application(self):
-        """Test add_application"""
+        """Testing deprecated method add_application"""
+
+        cfg = mock.create_autospec(Configuration)
+        cfg._log = logging.getLogger("add_application")
+        Configuration.add_application(cfg, "1", "2", three="3")
+        cfg.add_jobtype.assert_called_with("1", three="3")
+
+    def test_config_add_jobtype(self):
+        """Test add_jobtype"""
 
         _cfg = configparser.RawConfigParser()
         _cfg.add_section("TestApp")
         cfg = mock.create_autospec(Configuration)
-        cfg._log = logging.getLogger("add_application")
+        cfg._log = logging.getLogger("add_jobtype")
         cfg._config = _cfg
 
-        Configuration.add_application(cfg,
-                                      "TestApp",
-                                      "http://endpoint",
-                                      "test_id")
+        Configuration.add_jobtype(cfg,
+                                  "TestApp")
         self.assertEqual(cfg._config.sections(), ['TestApp'])
-        self.assertEqual(dict(cfg._config.items('TestApp')),
-                         {'endpoint':"http://endpoint", 'client_id':'test_id'})
+        self.assertEqual(dict(cfg._config.items('TestApp')), {})
 
-        Configuration.add_application(cfg,
-                                      "TestApp2",
-                                      "http://endpoint",
-                                      "test_id",
-                                      a="1",
-                                      b=2,
-                                      c=None)
+        Configuration.add_jobtype(cfg,
+                                  "TestApp2",
+                                  a="1",
+                                  b=2,
+                                  c=None)
         self.assertEqual(cfg._config.sections(), ['TestApp', 'TestApp2'])
         self.assertEqual(dict(cfg._config.items('TestApp2')),
-                         {'endpoint':"http://endpoint",
-                          'client_id':'test_id',
-                          'a':'1',
+                         {'a':'1',
                           'b':2,
                           'c':None})
 
@@ -543,12 +581,12 @@ class TestConfiguration(unittest.TestCase):
         cfg = mock.create_autospec(Configuration)
         cfg._log = logging.getLogger("config_set")
         cfg._config = _cfg
-        cfg.job_type = "TestApp"
+        cfg.jobtype = "TestApp"
 
         Configuration.set(cfg, "key", "value")
         self.assertEqual(dict(cfg._config.items('TestApp')), {'key':'value'})
 
-        cfg.job_type = "TestApp2"
+        cfg.jobtype = "TestApp2"
         with self.assertRaises(InvalidConfigException):
             Configuration.set(cfg, "key", "value")
 
@@ -560,12 +598,12 @@ class TestConfiguration(unittest.TestCase):
         cfg = mock.create_autospec(Configuration)
         cfg._log = logging.getLogger("config_get")
         cfg._config = _cfg
-        cfg.job_type = "TestApp2"
+        cfg.jobtype = "TestApp2"
 
         param = Configuration.get(cfg, "endpoint")
         self.assertIsNone(param)
 
-        cfg.job_type = "TestApp"
+        cfg.jobtype = "TestApp"
         param = Configuration.get(cfg, "endpoint")
         self.assertIsNone(param)
 
@@ -584,10 +622,10 @@ class TestConfiguration(unittest.TestCase):
         cfg = mock.create_autospec(Configuration)
         cfg._log = logging.getLogger("config_remove")
         cfg._config = _cfg
-        cfg.job_type = "TestApp"
+        cfg.jobtype = "TestApp"
 
-        with self.assertRaises(ValueError):
-            Configuration.remove(cfg, "TestApp")
+        rem = Configuration.remove(cfg, "TestApp")
+        self.assertFalse(rem)
 
         rem = Configuration.remove(cfg, "TestApp2")
         self.assertFalse(rem)
@@ -600,23 +638,16 @@ class TestConfiguration(unittest.TestCase):
 
         cfg._config.set("TestApp", "1", 1)
         cfg._config.set("TestApp", "2", 2)
-        cfg._config.set("TestApp", "endpoint", 3)
 
         rem = Configuration.remove(cfg, "1")
         self.assertTrue(rem)
-        self.assertEqual(dict(cfg._config.items('TestApp')),
-                         {'2':2, 'endpoint':3})
-
-        rem = Configuration.remove(cfg, "endpoint")
-        self.assertFalse(rem)
-        self.assertEqual(dict(cfg._config.items('TestApp')),
-                         {'2':2, 'endpoint':3})
+        self.assertEqual(dict(cfg._config.items('TestApp')), {'2':2})
 
         _cfg.add_section("Logging")
         rem = Configuration.remove(cfg, "Logging")
         self.assertFalse(rem)
 
-        cfg.job_type = "TestApp2"
+        cfg.jobtype = "TestApp2"
         rem = Configuration.remove(cfg, "TestApp")
         self.assertTrue(rem)
         self.assertEqual(cfg._config.sections(), ['Logging'])
@@ -628,10 +659,150 @@ class TestConfiguration(unittest.TestCase):
         cfg = mock.create_autospec(Configuration)
         cfg._log = logging.getLogger("aad")
         cfg._config = _cfg
+        cfg._reformat_config.return_value = {"a":1, "b":2}
+        cfg._validate_auth = lambda a: dict(_cfg.items("Authentication"))
 
         with self.assertRaises(InvalidConfigException):
             Configuration.aad_config(cfg)
 
         _cfg.add_section("Authentication")
         aad = Configuration.aad_config(cfg)
-        self.assertEqual(aad, {})
+        self.assertEqual(aad, {"a":1, "b":2})
+
+        aad = Configuration.aad_config(cfg, client_id="a", tenant="b",
+                                       endpoint="c")
+        self.assertEqual(aad, {"a":1, "b":2, "client_id":"a", "tenant":"b",
+                               "endpoint":"c"})
+        _cfg.remove_section("Authentication")
+        _cfg.add_section("Authentication")
+
+        _cfg.set("Authentication", "root", "test")
+        aad = Configuration.aad_config(cfg, key=3, redirect=4)
+        self.assertEqual(aad, {"root":"test", "unattended_key":"3",
+                               "redirect_uri":"4"})
+
+        _cfg.remove_section("Authentication")
+        _cfg.add_section("Authentication")
+        _cfg.set("Authentication", "root", "test")
+        
+        aad = Configuration.aad_config(cfg, account=3)
+        aad = Configuration.aad_config(cfg, account="test;test")
+        aad = Configuration.aad_config(cfg, account="ClientID=abc;TenantID=xyz")
+        self.assertEqual(aad, {"root":"test", "unattended_account":"ClientID=abc;TenantID=xyz"})
+
+        _cfg.remove_section("Authentication")
+        _cfg.add_section("Authentication")
+        _cfg.set("Authentication", "root", "test")
+
+        aad = Configuration.aad_config(cfg, account="ClientID=abc;TenantID=xyz",
+                                       client_id="foo", tenant="bar")
+        self.assertEqual(aad, {"root":"test", "client_id":"foo", "tenant":"bar",
+                               "unattended_account":"ClientID=abc;TenantID=xyz"})
+
+    def test_config_validate_auth(self):
+        """Test validate_auth"""
+        _cfg = configparser.RawConfigParser()
+        cfg = mock.create_autospec(Configuration)
+        cfg._invalid_data = lambda s: Configuration._invalid_data(cfg, s)
+        _cfg.add_section("Authentication")
+        cfg._config = _cfg
+        
+        with self.assertRaises(InvalidConfigException):
+            Configuration._validate_auth(cfg, False)
+
+        _cfg.set("Authentication", "auth_uri", "a")
+        _cfg.set("Authentication", "resource", "b")
+        _cfg.set("Authentication", "token_uri", "c")
+        _cfg.set("Authentication", "endpoint", "d")
+        _cfg.set("Authentication", "client_id", "e")
+        _cfg.set("Authentication", "tenant", "f")
+        _cfg.set("Authentication", "root", "g")
+        _cfg.set("Authentication", "redirect_uri", "{redirect}")
+
+        with self.assertRaises(InvalidConfigException):
+            Configuration._validate_auth(cfg, False)
+
+        _cfg.set("Authentication", "redirect_uri", "h")
+        auth = Configuration._validate_auth(cfg, False)
+
+        with self.assertRaises(InvalidConfigException):
+            Configuration._validate_auth(cfg, True)
+
+        _cfg.set("Authentication", "unattended_account", None)
+        _cfg.set("Authentication", "unattended_key", "i")
+
+        with self.assertRaises(InvalidConfigException):
+            Configuration._validate_auth(cfg, True)
+
+        _cfg.set("Authentication", "unattended_account", "j")
+        auth = Configuration._validate_auth(cfg, True)
+
+        _cfg.remove_option("Authentication", "redirect_uri")
+        auth = Configuration._validate_auth(cfg, True)
+
+    def test_config_reformat_config(self):
+        """Test reformat_config"""
+
+        old_cfg = configparser.RawConfigParser()
+        old_cfg.add_section("Authentication")
+        old_cfg.set("Authentication", "auth_uri",
+                    "login.windows.net/common/oauth2/authorize")
+        old_cfg.set("Authentication", "resource", "https://batchapps.core.windows.net/")
+        old_cfg.set("Authentication", "token_uri", "login.windows.net/common/oauth2/token")
+        
+        old_cfg.add_section("TestJob")
+        old_cfg.set("TestJob", "endpoint", "test.com")
+        old_cfg.set("TestJob", "client_id", "abc")
+        old_cfg.set("TestJob", "redirect_uri", "redirect.com")
+
+        cfg = mock.create_autospec(Configuration)
+        cfg._log = logging.getLogger("aad")
+        cfg._config = old_cfg
+        cfg.jobtype = "TestJob"
+
+        aad = Configuration._reformat_config(
+            cfg, dict(cfg._config.items("Authentication")))
+
+        self.assertEqual(aad, {"endpoint":"test.com", "client_id":"abc",
+                               "auth_uri":"/oauth2/authorize",
+                               "root":"login.windows.net/",
+                               "token_uri":"/oauth2/token",
+                               "redirect_uri":"redirect.com",
+                               "unattended_account":None,
+                               "unattended_key":None,
+                               "tenant":"common",
+                               "resource":"https://batchapps.core.windows.net/"})
+
+        old_cfg.set("Authentication", "service_principal", "")
+        old_cfg.set("Authentication", "service_principal_key", "")
+
+        aad = Configuration._reformat_config(
+            cfg, dict(cfg._config.items("Authentication")))
+
+        self.assertEqual(aad, {"endpoint":"test.com", "client_id":"abc",
+                               "auth_uri":"/oauth2/authorize",
+                               "root":"login.windows.net/",
+                               "token_uri":"/oauth2/token",
+                               "redirect_uri":"redirect.com",
+                               "unattended_account":"",
+                               "unattended_key":"",
+                               "tenant":"common",
+                               "resource":"https://batchapps.core.windows.net/"})
+
+        old_cfg.set("Authentication", "service_principal_key", "%&#5$#")
+        old_cfg.set("Authentication", "service_principal",
+                    "ClientId=xyz;TenantId=test_account.onmicrosoft.com")
+
+        aad = Configuration._reformat_config(
+            cfg, dict(cfg._config.items("Authentication")))
+
+        self.assertEqual(aad, {"endpoint":"test.com", "client_id":"abc",
+                               "auth_uri":"/oauth2/authorize",
+                               "root":"login.windows.net/",
+                               "token_uri":"/oauth2/token",
+                               "redirect_uri":"redirect.com",
+                               "unattended_account":"ClientId=xyz;TenantId=test_account.onmicrosoft.com",
+                               "unattended_key":"%&#5$#",
+                               "tenant":"common",
+                               "resource":"https://batchapps.core.windows.net/"})
+
