@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------
-# The Azure Batch Apps Python Client ver. 0.1.0
+# The Azure Batch Apps Python Client
 #
 # Copyright (c) Microsoft Corporation. All rights reserved. 
 #
@@ -278,6 +278,29 @@ class TestFileCollection(unittest.TestCase):
         self.assertTrue(all(i in [test_file, test_file2]
                             for i in col._collection))
 
+    @mock.patch('batchapps.api.BatchAppsApi')
+    def test_filecoll_index(self, mock_api):
+        """Test index"""
+
+        col = FileCollection(mock_api)
+
+        test_file = mock.create_autospec(UserFile)
+        test_file2 = mock.create_autospec(UserFile)
+        test_file3 = mock.create_autospec(UserFile)
+
+        col._collection = [test_file, test_file2]
+
+        with self.assertRaises(TypeError):
+            col.index(None)
+        with self.assertRaises(TypeError):
+            col.index("test")
+
+        with self.assertRaises(ValueError):
+            col.index(test_file3)
+
+        self.assertEqual(col._collection.index(test_file2), 1)
+
+
     @mock.patch('batchapps.api.BatchAppsApi')
     def test_filecoll_remove(self, mock_api):
         """Test remove"""
