@@ -41,6 +41,7 @@ except ImportError:
 import tempfile
 from operator import itemgetter
 from batchapps.utils import Listener
+from batchapps.pool import Pool, PoolSpecifier
 from batchapps.api import (
     BatchAppsApi,
     Response)
@@ -151,12 +152,37 @@ class TestJobSubmission(unittest.TestCase):
                                  {"Name":"k1", "Value":"v1"}],
                                 key=itemgetter('Name')))
 
+    @mock.patch('batchapps.job.PoolSpecifier')
+    def test_jobsubmission_auto_pool(self, mock_pool):
+        """Test _auto_pool"""
+
+        api = mock.create_autospec(BatchAppsApi)
+        api.jobtype.return_value = "TestApp"
+        mock_pool.return_value = mock.create_autospec(PoolSpecifier)
+        mock_pool.return_value.target_size = 5
+        mock_pool.return_value.max_tasks = 2
+        mock_pool.return_value.communication = False
+        mock_pool.return_value.certificates = []
+
+        job = JobSubmission(api, "test_job", params={})
+        pool = job._auto_pool(4)
+
+        mock_pool.assert_called_with(mock.ANY, target_size=4)
+        self.assertEqual(pool, {
+            'targetDedicated': "5",
+            'maxTasksPerTVM': "2",
+            'communication': False,
+            'certificateReferences': []
+            })
+
+    @mock.patch.object(JobSubmission, '_auto_pool')
     @mock.patch.object(JobSubmission, '_filter_params')
-    def test_jobsubmission_create_job_message(self, mock_filter):
+    def test_jobsubmission_create_job_message(self, mock_filter, mock_pool):
         """Test _create_job_message"""
 
         api = mock.create_autospec(BatchAppsApi)
         api.jobtype.return_value = "TestApp"
+        mock_pool.return_value = {"autopool":"0"}
         files = mock.create_autospec(FileCollection)
         files._get_message.return_value = ["file1", "file2"]
         files.__len__.return_value = 2
@@ -166,21 +192,24 @@ class TestJobSubmission(unittest.TestCase):
 
         #with self.assertRaises(ValueError):
         msg = job._create_job_message()
+        self.assertTrue(mock_pool.called)
         self.assertEqual(msg, {'Name':'test_job',
                                'Type': 'TestApp',
                                'RequiredFiles':[],
-                               'Pool': {'InstanceCount':'0'},
+                               'autoPoolSpecification': {"autopool":"0"},
                                'Parameters':[{"Name":"k1", "Value":"v1"}],
                                'JobFile':'',
                                'Settings':'',
                                'Priority':'Medium'})
 
         job.required_files = files
+        job.instances = 5
         msg = job._create_job_message()
+        mock_pool.assert_called_with(5)
         self.assertEqual(msg, {'Name':'test_job',
                                'Type': 'TestApp',
                                'RequiredFiles':["file1", "file2"],
-                               'Pool': {'InstanceCount':'0'},
+                               'autoPoolSpecification': {"autopool":"0"},
                                'Parameters':[{"Name":"k1", "Value":"v1"}],
                                'JobFile':'',
                                'Settings':'',
@@ -190,16 +219,25 @@ class TestJobSubmission(unittest.TestCase):
         job.instances = []
         job.type = 42
         job.name = {}
+        job.pool = "testID"
 
-        with self.assertRaises(TypeError):
-            job._create_job_message()
-
-        job.instances = "100"
         msg = job._create_job_message()
         self.assertEqual(msg, {'Name':'{}',
                                'Type': 'TestApp',
                                'RequiredFiles':["file1", "file2"],
-                               'Pool': {'InstanceCount':'100'},
+                               'poolId': "testID",
+                               'Parameters':[{"Name":"k1", "Value":"v1"}],
+                               'JobFile':'None',
+                               'Settings':'',
+                               'Priority':'Medium'})
+
+        job.pool = mock.create_autospec(Pool)
+        job.pool.id = "differentID"
+        msg = job._create_job_message()
+        self.assertEqual(msg, {'Name':'{}',
+                               'Type': 'TestApp',
+                               'RequiredFiles':["file1", "file2"],
+                               'poolId': "differentID",
                                'Parameters':[{"Name":"k1", "Value":"v1"}],
                                'JobFile':'None',
                                'Settings':'',
@@ -292,11 +330,13 @@ class TestJobSubmission(unittest.TestCase):
         with self.assertRaises(RestCallException):
             job.submit()
         api.send_job.assert_called_with("{message}")
+        mock_message.assert_called_with()
 
         resp.success = True
-        resp.result = {'jobId':'abc'}
+        resp.result = {'jobId':'abc', 'link':{'href':'test'}}
         sub = job.submit()
-        self.assertEqual(sub, {'jobId':'abc'})
+        mock_message.assert_called_with()
+        self.assertEqual(sub, {'jobId':'abc', 'id':'abc', 'link':'test'})
 
 
 # pylint: disable=W0212
